==> jc-1.4.0.tar.gz: scm/primnode.c <==
// class scm.primnode

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 7cdfd1539eaf66a scm_Env
// @dep_class 43c5b3625f6dab19 scm_Obj
// @dep_class c6ba42ad8737f7d0 scm_primnode

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header scm_Env
// @dep_header scm_Obj
// @dep_header scm_primnode

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "scm/Env.h"
#include "scm/Obj.h"
#include "scm/primnode.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.Object val
static _jc_field _jc_scm_primnode$field_info$val = {
	.name=		"val",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_scm_primnode$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_scm_primnode$object, refs[-1].scm_primnode.val),
};

// Fields
static _jc_field *const _jc_scm_primnode$fields[] = {
	&_jc_scm_primnode$field_info$val
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.lang.Object)
//

static _jc_linenum _jc_scm_primnode$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_scm_primnode$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_scm_primnode$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_scm_primnode$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_scm_primnode$type,
	.param_types=		&_jc_scm_primnode$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		0,
	.function=		&_jc_scm_primnode$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, _init$3fddd28dadb712ab);

void
_jc_scm_primnode$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_scm_primnode$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(12);				// 0
	_JC_REF_FIELD(env, r0, scm_primnode, val) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public scm.Obj eval(scm.Env)
//

static _jc_linenum _jc_scm_primnode$linenum_table$eval$45e01bedb73fc9c4[];

static const unsigned char _jc_scm_primnode$param_ptypes$eval$45e01bedb73fc9c4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_scm_primnode$param_types$eval$45e01bedb73fc9c4[] = {
	&_jc_scm_Env$type
};

_jc_method _jc_scm_primnode$method_info$eval$45e01bedb73fc9c4 = {
	.name=			"eval",
	.signature=		"(Lscm/Env;)Lscm/Obj;",
	.class=			&_jc_scm_primnode$type,
	.param_types=		&_jc_scm_primnode$param_types$eval$45e01bedb73fc9c4,
	.return_type=		&_jc_scm_Obj$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$eval$45e01bedb73fc9c4,
	.signature_hash=	_JC_JLONG(0x45e01bedb73fc9c4),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_primnode$method$eval$45e01bedb73fc9c4,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_primnode$vtable, scm_primnode.eval$45e01bedb73fc9c4) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$eval$45e01bedb73fc9c4
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, eval$45e01bedb73fc9c4);

_jc_object *
_jc_scm_primnode$method$eval$45e01bedb73fc9c4(_jc_env *const env, _jc_scm_primnode$object *this, _jc_scm_Env$object *param0)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_scm_Env$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(10);				// 0
	return r0;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_scm_primnode$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_scm_primnode$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_scm_primnode$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_scm_primnode$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_primnode$vtable, scm_primnode.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_scm_primnode$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_scm_primnode$object *this)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_String$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	r1 = _JC_REF_FIELD(env, r0, scm_primnode, val);
	r2 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_scm_primnode$methods[] = {
	&_jc_scm_primnode$method_info$_init$3fddd28dadb712ab,
	&_jc_scm_primnode$method_info$eval$45e01bedb73fc9c4,
	&_jc_scm_primnode$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_scm_primnode$interfaces[] = {
	&_jc_scm_Obj$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_scm_primnode$imethod_hash_bucket_68[] = {
	&_jc_scm_primnode$method_info$eval$45e01bedb73fc9c4,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_scm_primnode$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	_jc_scm_primnode$imethod_hash_bucket_68
};

// Interface "quick" lookup hash table
static const void *_jc_scm_primnode$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	&_jc_scm_primnode$method$eval$45e01bedb73fc9c4
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_25[] = {
	&_jc_scm_Obj$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_80[] = {
	&_jc_scm_primnode$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_scm_primnode$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[25]=	_jc_scm_primnode$instanceof_hash_bucket_25,
	[80]=	_jc_scm_primnode$instanceof_hash_bucket_80,
	[113]=	_jc_scm_primnode$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_scm_primnode$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "scm/Env",	_JC_JLONG(0x7cdfd1539eaf66a) },
	{ "scm/Obj",	_JC_JLONG(0x43c5b3625f6dab19) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_scm_primnode$vtype _jc_scm_primnode$type = {
    .type= {
	.name=			"scm/primnode",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_scm_primnode$interfaces) / sizeof(*_jc_scm_primnode$interfaces),
	.interfaces=		_jc_scm_primnode$interfaces,
	.imethod_hash_table=	_jc_scm_primnode$imethod_hash_table,
	.imethod_quick_table=	_jc_scm_primnode$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xc6ba42ad8737f7d0),
		.source_file=		"primnode.java",
		.instance_size=		sizeof(_jc_scm_primnode$refs) + sizeof(_jc_scm_primnode$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_scm_primnode$fields) / sizeof(*_jc_scm_primnode$fields),
		.fields=		_jc_scm_primnode$fields,
		.num_methods=		sizeof(_jc_scm_primnode$methods) / sizeof(*_jc_scm_primnode$methods),
		.methods=		_jc_scm_primnode$methods,
		.instanceof_hash_table=	_jc_scm_primnode$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_scm_primnode$class_depends) / sizeof(*_jc_scm_primnode$class_depends),
		.class_depends=		_jc_scm_primnode$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.scm_primnode= {
	    .eval$45e01bedb73fc9c4=
		&_jc_scm_primnode$method$eval$45e01bedb73fc9c4,
	    .toString$7ea43b33b80a3070=
		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: scm/primnode.c <==
// class scm.primnode

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 7cdfd1539eaf66a scm_Env
// @dep_class 43c5b3625f6dab19 scm_Obj
// @dep_class c6ba42ad8737f7d0 scm_primnode

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header scm_Env
// @dep_header scm_Obj
// @dep_header scm_primnode

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "scm/Env.h"
#include "scm/Obj.h"
#include "scm/primnode.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.Object val
static _jc_field _jc_scm_primnode$field_info$val = {
	.name=		"val",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_scm_primnode$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_scm_primnode$object, refs[-1].scm_primnode.val),
};

// Fields
static _jc_field *const _jc_scm_primnode$fields[] = {
	&_jc_scm_primnode$field_info$val
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.lang.Object)
//

static _jc_linenum _jc_scm_primnode$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_scm_primnode$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_scm_primnode$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_scm_primnode$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_scm_primnode$type,
	.param_types=		&_jc_scm_primnode$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		0,
	.function=		&_jc_scm_primnode$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, _init$3fddd28dadb712ab);

void _JC_JCNI_ATTR
_jc_scm_primnode$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_scm_primnode$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(12);				// 0
	_JC_REF_FIELD(env, r0, scm_primnode, val) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public scm.Obj eval(scm.Env)
//

static _jc_linenum _jc_scm_primnode$linenum_table$eval$45e01bedb73fc9c4[];

static const unsigned char _jc_scm_primnode$param_ptypes$eval$45e01bedb73fc9c4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_scm_primnode$param_types$eval$45e01bedb73fc9c4[] = {
	&_jc_scm_Env$type
};

_jc_method _jc_scm_primnode$method_info$eval$45e01bedb73fc9c4 = {
	.name=			"eval",
	.signature=		"(Lscm/Env;)Lscm/Obj;",
	.class=			&_jc_scm_primnode$type,
	.param_types=		&_jc_scm_primnode$param_types$eval$45e01bedb73fc9c4,
	.return_type=		&_jc_scm_Obj$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$eval$45e01bedb73fc9c4,
	.signature_hash=	_JC_JLONG(0x45e01bedb73fc9c4),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_primnode$method$eval$45e01bedb73fc9c4,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_primnode$vtable, scm_primnode.eval$45e01bedb73fc9c4) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$eval$45e01bedb73fc9c4
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, eval$45e01bedb73fc9c4);

_jc_object * _JC_JCNI_ATTR
_jc_scm_primnode$method$eval$45e01bedb73fc9c4(_jc_env *const env, _jc_scm_primnode$object *this, _jc_scm_Env$object *param0)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_scm_Env$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(10);				// 0
	return r0;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_scm_primnode$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_scm_primnode$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_scm_primnode$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_scm_primnode$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_scm_primnode$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_scm_primnode$vtable, scm_primnode.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_scm_primnode$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(scm_primnode, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_scm_primnode$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_scm_primnode$object *this)
{
	struct _jc_scm_primnode$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_String$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(14);				// 0
	r1 = _JC_REF_FIELD(env, r0, scm_primnode, val);
	r2 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_scm_primnode$methods[] = {
	&_jc_scm_primnode$method_info$_init$3fddd28dadb712ab,
	&_jc_scm_primnode$method_info$eval$45e01bedb73fc9c4,
	&_jc_scm_primnode$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_scm_primnode$interfaces[] = {
	&_jc_scm_Obj$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_scm_primnode$imethod_hash_bucket_68[] = {
	&_jc_scm_primnode$method_info$eval$45e01bedb73fc9c4,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_scm_primnode$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	_jc_scm_primnode$imethod_hash_bucket_68
};

// Interface "quick" lookup hash table
static const void *_jc_scm_primnode$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[68]=	&_jc_scm_primnode$method$eval$45e01bedb73fc9c4
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_25[] = {
	&_jc_scm_Obj$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_80[] = {
	&_jc_scm_primnode$type,
	_JC_NULL
};
static _jc_type *const _jc_scm_primnode$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_scm_primnode$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[25]=	_jc_scm_primnode$instanceof_hash_bucket_25,
	[80]=	_jc_scm_primnode$instanceof_hash_bucket_80,
	[101]=	_jc_scm_primnode$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_scm_primnode$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "scm/Env",	_JC_JLONG(0x7cdfd1539eaf66a) },
	{ "scm/Obj",	_JC_JLONG(0x43c5b3625f6dab19) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_scm_primnode$vtype _jc_scm_primnode$type = {
    .type= {
	.name=			"scm/primnode",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_scm_primnode$interfaces) / sizeof(*_jc_scm_primnode$interfaces),
	.interfaces=		_jc_scm_primnode$interfaces,
	.imethod_hash_table=	_jc_scm_primnode$imethod_hash_table,
	.imethod_quick_table=	_jc_scm_primnode$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xc6ba42ad8737f7d0),
		.source_file=		"primnode.java",
		.instance_size=		sizeof(_jc_scm_primnode$refs) + sizeof(_jc_scm_primnode$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_scm_primnode$fields) / sizeof(*_jc_scm_primnode$fields),
		.fields=		_jc_scm_primnode$fields,
		.num_methods=		sizeof(_jc_scm_primnode$methods) / sizeof(*_jc_scm_primnode$methods),
		.methods=		_jc_scm_primnode$methods,
		.instanceof_hash_table=	_jc_scm_primnode$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_scm_primnode$class_depends) / sizeof(*_jc_scm_primnode$class_depends),
		.class_depends=		_jc_scm_primnode$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.scm_primnode= {
	    .eval$45e01bedb73fc9c4=
		&_jc_scm_primnode$method$eval$45e01bedb73fc9c4,
	    .toString$7ea43b33b80a3070=
		&_jc_scm_primnode$method$toString$7ea43b33b80a3070,
	},
    }
};
